summaryrefslogtreecommitdiff
path: root/PLUGINS
diff options
context:
space:
mode:
Diffstat (limited to 'PLUGINS')
-rw-r--r--PLUGINS/src/hello/Makefile4
-rw-r--r--PLUGINS/src/hello/README6
-rw-r--r--PLUGINS/src/hello/po/ca_ES.po4
-rw-r--r--PLUGINS/src/hello/po/cs_CZ.po4
-rw-r--r--PLUGINS/src/hello/po/da_DK.po4
-rw-r--r--PLUGINS/src/hello/po/de_DE.po8
-rw-r--r--PLUGINS/src/hello/po/el_GR.po4
-rw-r--r--PLUGINS/src/hello/po/es_ES.po4
-rw-r--r--PLUGINS/src/hello/po/et_EE.po4
-rw-r--r--PLUGINS/src/hello/po/fi_FI.po4
-rw-r--r--PLUGINS/src/hello/po/fr_FR.po4
-rw-r--r--PLUGINS/src/hello/po/hr_HR.po4
-rw-r--r--PLUGINS/src/hello/po/hu_HU.po4
-rw-r--r--PLUGINS/src/hello/po/it_IT.po4
-rw-r--r--PLUGINS/src/hello/po/nl_NL.po4
-rw-r--r--PLUGINS/src/hello/po/nn_NO.po4
-rw-r--r--PLUGINS/src/hello/po/pl_PL.po4
-rw-r--r--PLUGINS/src/hello/po/pt_PT.po4
-rw-r--r--PLUGINS/src/hello/po/ro_RO.po4
-rw-r--r--PLUGINS/src/hello/po/ru_RU.po4
-rw-r--r--PLUGINS/src/hello/po/sl_SI.po4
-rw-r--r--PLUGINS/src/hello/po/sv_SE.po4
-rw-r--r--PLUGINS/src/hello/po/tr_TR.po4
-rw-r--r--PLUGINS/src/osddemo/README6
-rw-r--r--PLUGINS/src/pictures/Makefile4
-rw-r--r--PLUGINS/src/pictures/README6
-rw-r--r--PLUGINS/src/pictures/po/de_DE.po8
-rw-r--r--PLUGINS/src/pictures/po/fi_FI.po4
-rw-r--r--PLUGINS/src/pictures/po/fr_FR.po4
-rw-r--r--PLUGINS/src/pictures/po/it_IT.po4
-rw-r--r--PLUGINS/src/pictures/po/ru_RU.po4
-rw-r--r--PLUGINS/src/servicedemo/README4
-rw-r--r--PLUGINS/src/skincurses/Makefile4
-rw-r--r--PLUGINS/src/skincurses/README6
-rw-r--r--PLUGINS/src/skincurses/po/de_DE.po8
-rw-r--r--PLUGINS/src/skincurses/po/fi_FI.po4
-rw-r--r--PLUGINS/src/skincurses/po/it_IT.po4
-rw-r--r--PLUGINS/src/skincurses/po/ru_RU.po4
-rw-r--r--PLUGINS/src/sky/README6
-rwxr-xr-xPLUGINS/src/sky/getskyepg.pl6
-rw-r--r--PLUGINS/src/status/README6
-rw-r--r--PLUGINS/src/svdrpdemo/README6
42 files changed, 98 insertions, 98 deletions
diff --git a/PLUGINS/src/hello/Makefile b/PLUGINS/src/hello/Makefile
index c4ea46fd..ea5b8063 100644
--- a/PLUGINS/src/hello/Makefile
+++ b/PLUGINS/src/hello/Makefile
@@ -1,7 +1,7 @@
#
# Makefile for a Video Disk Recorder plugin
#
-# $Id: Makefile 1.22 2008/01/13 12:59:58 kls Exp $
+# $Id: Makefile 2.1 2009/10/18 14:00:07 kls Exp $
# The official name of this plugin.
# This name will be used in the '-P...' option of VDR to load the plugin.
@@ -79,7 +79,7 @@ I18Npot = $(PODIR)/$(PLUGIN).pot
msgfmt -c -o $@ $<
$(I18Npot): $(wildcard *.c)
- xgettext -C -cTRANSLATORS --no-wrap --no-location -k -ktr -ktrNOOP --msgid-bugs-address='<vdr-bugs@cadsoft.de>' -o $@ $^
+ xgettext -C -cTRANSLATORS --no-wrap --no-location -k -ktr -ktrNOOP --msgid-bugs-address='<vdr-bugs@tvdr.de>' -o $@ $^
%.po: $(I18Npot)
msgmerge -U --no-wrap --no-location --backup=none -q $@ $<
diff --git a/PLUGINS/src/hello/README b/PLUGINS/src/hello/README
index 5c5d3b0d..e3c46a9d 100644
--- a/PLUGINS/src/hello/README
+++ b/PLUGINS/src/hello/README
@@ -1,10 +1,10 @@
This is a "plugin" for the Video Disk Recorder (VDR).
-Written by: Klaus Schmidinger <kls@cadsoft.de>
+Written by: Klaus Schmidinger <kls@tvdr.de>
-Project's homepage: www.cadsoft.de/people/kls/vdr
+Project's homepage: http://www.tvdr.de
-Latest version available at: www.cadsoft.de/people/kls/vdr/software.htm
+Latest version available at: http://www.tvdr.de
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
diff --git a/PLUGINS/src/hello/po/ca_ES.po b/PLUGINS/src/hello/po/ca_ES.po
index 6d6e0152..008b97ed 100644
--- a/PLUGINS/src/hello/po/ca_ES.po
+++ b/PLUGINS/src/hello/po/ca_ES.po
@@ -1,5 +1,5 @@
# VDR plugin language source file.
-# Copyright (C) 2008 Klaus Schmidinger <kls@cadsoft.de>
+# Copyright (C) 2008 Klaus Schmidinger <kls@tvdr.de>
# This file is distributed under the same license as the VDR package.
# Marc Rovira Vall <tm05462@salleURL.edu>, 2003
# Ramon Roca <ramon.roca@xcombo.com>, 2003
@@ -8,7 +8,7 @@
msgid ""
msgstr ""
"Project-Id-Version: VDR 1.6.0\n"
-"Report-Msgid-Bugs-To: <vdr-bugs@cadsoft.de>\n"
+"Report-Msgid-Bugs-To: <vdr-bugs@tvdr.de>\n"
"POT-Creation-Date: 2007-10-13 11:52+0200\n"
"PO-Revision-Date: 2007-08-11 12:34+0200\n"
"Last-Translator: Jordi Vilŕ <jvila@tinet.org>\n"
diff --git a/PLUGINS/src/hello/po/cs_CZ.po b/PLUGINS/src/hello/po/cs_CZ.po
index d90d417e..c4fa5713 100644
--- a/PLUGINS/src/hello/po/cs_CZ.po
+++ b/PLUGINS/src/hello/po/cs_CZ.po
@@ -1,12 +1,12 @@
# VDR plugin language source file.
-# Copyright (C) 2008 Klaus Schmidinger <kls@cadsoft.de>
+# Copyright (C) 2008 Klaus Schmidinger <kls@tvdr.de>
# This file is distributed under the same license as the VDR package.
# Vladimír Bárta <vladimir.barta@k2atmitec.cz>, 2006
#
msgid ""
msgstr ""
"Project-Id-Version: VDR 1.6.0\n"
-"Report-Msgid-Bugs-To: <vdr-bugs@cadsoft.de>\n"
+"Report-Msgid-Bugs-To: <vdr-bugs@tvdr.de>\n"
"POT-Creation-Date: 2007-10-13 11:52+0200\n"
"PO-Revision-Date: 2007-08-11 12:34+0200\n"
"Last-Translator: Vladimír Bárta <vladimir.barta@k2atmitec.cz>\n"
diff --git a/PLUGINS/src/hello/po/da_DK.po b/PLUGINS/src/hello/po/da_DK.po
index 904f4d52..f05412a1 100644
--- a/PLUGINS/src/hello/po/da_DK.po
+++ b/PLUGINS/src/hello/po/da_DK.po
@@ -1,12 +1,12 @@
# VDR plugin language source file.
-# Copyright (C) 2008 Klaus Schmidinger <kls@cadsoft.de>
+# Copyright (C) 2008 Klaus Schmidinger <kls@tvdr.de>
# This file is distributed under the same license as the VDR package.
# Mogens Elneff <mogens@elneff.dk>, 2004
#
msgid ""
msgstr ""
"Project-Id-Version: VDR 1.6.0\n"
-"Report-Msgid-Bugs-To: <vdr-bugs@cadsoft.de>\n"
+"Report-Msgid-Bugs-To: <vdr-bugs@tvdr.de>\n"
"POT-Creation-Date: 2007-10-13 11:52+0200\n"
"PO-Revision-Date: 2007-08-11 12:34+0200\n"
"Last-Translator: Mogens Elneff <mogens@elneff.dk>\n"
diff --git a/PLUGINS/src/hello/po/de_DE.po b/PLUGINS/src/hello/po/de_DE.po
index aef2ca77..43d6f2b7 100644
--- a/PLUGINS/src/hello/po/de_DE.po
+++ b/PLUGINS/src/hello/po/de_DE.po
@@ -1,15 +1,15 @@
# VDR plugin language source file.
-# Copyright (C) 2008 Klaus Schmidinger <kls@cadsoft.de>
+# Copyright (C) 2008 Klaus Schmidinger <kls@tvdr.de>
# This file is distributed under the same license as the VDR package.
-# Klaus Schmidinger <kls@cadsoft.de>, 2000
+# Klaus Schmidinger <kls@tvdr.de>, 2000
#
msgid ""
msgstr ""
"Project-Id-Version: VDR 1.6.0\n"
-"Report-Msgid-Bugs-To: <vdr-bugs@cadsoft.de>\n"
+"Report-Msgid-Bugs-To: <vdr-bugs@tvdr.de>\n"
"POT-Creation-Date: 2007-10-13 11:52+0200\n"
"PO-Revision-Date: 2007-08-11 12:34+0200\n"
-"Last-Translator: Klaus Schmidinger <kls@cadsoft.de>\n"
+"Last-Translator: Klaus Schmidinger <kls@tvdr.de>\n"
"Language-Team: German\n"
"MIME-Version: 1.0\n"
"Content-Type: text/plain; charset=ISO-8859-15\n"
diff --git a/PLUGINS/src/hello/po/el_GR.po b/PLUGINS/src/hello/po/el_GR.po
index a0366c0f..adcb3cd9 100644
--- a/PLUGINS/src/hello/po/el_GR.po
+++ b/PLUGINS/src/hello/po/el_GR.po
@@ -1,12 +1,12 @@
# VDR plugin language source file.
-# Copyright (C) 2008 Klaus Schmidinger <kls@cadsoft.de>
+# Copyright (C) 2008 Klaus Schmidinger <kls@tvdr.de>
# This file is distributed under the same license as the VDR package.
# Dimitrios Dimitrakos <mail@dimitrios.de>, 2002
#
msgid ""
msgstr ""
"Project-Id-Version: VDR 1.6.0\n"
-"Report-Msgid-Bugs-To: <vdr-bugs@cadsoft.de>\n"
+"Report-Msgid-Bugs-To: <vdr-bugs@tvdr.de>\n"
"POT-Creation-Date: 2007-10-13 11:52+0200\n"
"PO-Revision-Date: 2007-08-11 12:34+0200\n"
"Last-Translator: Dimitrios Dimitrakos <mail@dimitrios.de>\n"
diff --git a/PLUGINS/src/hello/po/es_ES.po b/PLUGINS/src/hello/po/es_ES.po
index a5f3bf2b..33af9695 100644
--- a/PLUGINS/src/hello/po/es_ES.po
+++ b/PLUGINS/src/hello/po/es_ES.po
@@ -1,12 +1,12 @@
# VDR plugin language source file.
-# Copyright (C) 2008 Klaus Schmidinger <kls@cadsoft.de>
+# Copyright (C) 2008 Klaus Schmidinger <kls@tvdr.de>
# This file is distributed under the same license as the VDR package.
# Ruben Nunez Francisco <ruben.nunez@tang-it.com>, 2002
#
msgid ""
msgstr ""
"Project-Id-Version: VDR 1.6.0\n"
-"Report-Msgid-Bugs-To: <vdr-bugs@cadsoft.de>\n"
+"Report-Msgid-Bugs-To: <vdr-bugs@tvdr.de>\n"
"POT-Creation-Date: 2007-10-13 11:52+0200\n"
"PO-Revision-Date: 2007-08-11 12:34+0200\n"
"Last-Translator: Ruben Nunez Francisco <ruben.nunez@tang-it.com>\n"
diff --git a/PLUGINS/src/hello/po/et_EE.po b/PLUGINS/src/hello/po/et_EE.po
index 2fefc5d8..f83d03c0 100644
--- a/PLUGINS/src/hello/po/et_EE.po
+++ b/PLUGINS/src/hello/po/et_EE.po
@@ -1,12 +1,12 @@
# VDR plugin language source file.
-# Copyright (C) 2008 Klaus Schmidinger <kls@cadsoft.de>
+# Copyright (C) 2008 Klaus Schmidinger <kls@tvdr.de>
# This file is distributed under the same license as the VDR package.
# Arthur Konovalov <kasjas@hot.ee>, 2004
#
msgid ""
msgstr ""
"Project-Id-Version: VDR 1.6.0\n"
-"Report-Msgid-Bugs-To: <vdr-bugs@cadsoft.de>\n"
+"Report-Msgid-Bugs-To: <vdr-bugs@tvdr.de>\n"
"POT-Creation-Date: 2007-10-13 11:52+0200\n"
"PO-Revision-Date: 2007-08-11 12:34+0200\n"
"Last-Translator: Arthur Konovalov <kasjas@hot.ee>\n"
diff --git a/PLUGINS/src/hello/po/fi_FI.po b/PLUGINS/src/hello/po/fi_FI.po
index 68d723c8..476fe4cd 100644
--- a/PLUGINS/src/hello/po/fi_FI.po
+++ b/PLUGINS/src/hello/po/fi_FI.po
@@ -1,5 +1,5 @@
# VDR plugin language source file.
-# Copyright (C) 2008 Klaus Schmidinger <kls@cadsoft.de>
+# Copyright (C) 2008 Klaus Schmidinger <kls@tvdr.de>
# This file is distributed under the same license as the VDR package.
# Hannu Savolainen <hannu@opensound.com>, 2002
# Jaakko Hyvätti <jaakko@hyvatti.iki.fi>, 2002
@@ -9,7 +9,7 @@
msgid ""
msgstr ""
"Project-Id-Version: VDR 1.6.0\n"
-"Report-Msgid-Bugs-To: <vdr-bugs@cadsoft.de>\n"
+"Report-Msgid-Bugs-To: <vdr-bugs@tvdr.de>\n"
"POT-Creation-Date: 2007-10-13 11:52+0200\n"
"PO-Revision-Date: 2007-08-11 12:34+0200\n"
"Last-Translator: Rolf Ahrenberg <rahrenbe@cc.hut.fi>\n"
diff --git a/PLUGINS/src/hello/po/fr_FR.po b/PLUGINS/src/hello/po/fr_FR.po
index 6b69f3ba..6adcce52 100644
--- a/PLUGINS/src/hello/po/fr_FR.po
+++ b/PLUGINS/src/hello/po/fr_FR.po
@@ -1,5 +1,5 @@
# VDR plugin language source file.
-# Copyright (C) 2008 Klaus Schmidinger <kls@cadsoft.de>
+# Copyright (C) 2008 Klaus Schmidinger <kls@tvdr.de>
# This file is distributed under the same license as the VDR package.
# Jean-Claude Repetto <jc@repetto.org>, 2001
# Olivier Jacques <jacquesolivier@hotmail.com>, 2003
@@ -9,7 +9,7 @@
msgid ""
msgstr ""
"Project-Id-Version: VDR 1.6.0\n"
-"Report-Msgid-Bugs-To: <vdr-bugs@cadsoft.de>\n"
+"Report-Msgid-Bugs-To: <vdr-bugs@tvdr.de>\n"
"POT-Creation-Date: 2007-10-13 11:52+0200\n"
"PO-Revision-Date: 2007-08-11 12:34+0200\n"
"Last-Translator: Nicolas Huillard <nhuillard@e-dition.fr>\n"
diff --git a/PLUGINS/src/hello/po/hr_HR.po b/PLUGINS/src/hello/po/hr_HR.po
index 5f0d7b74..752d1edd 100644
--- a/PLUGINS/src/hello/po/hr_HR.po
+++ b/PLUGINS/src/hello/po/hr_HR.po
@@ -1,12 +1,12 @@
# VDR plugin language source file.
-# Copyright (C) 2008 Klaus Schmidinger <kls@cadsoft.de>
+# Copyright (C) 2008 Klaus Schmidinger <kls@tvdr.de>
# This file is distributed under the same license as the VDR package.
# Adrian Caval <anrxc@sysphere.org>, 2008
#
msgid ""
msgstr ""
"Project-Id-Version: VDR 1.6.0\n"
-"Report-Msgid-Bugs-To: <vdr-bugs@cadsoft.de>\n"
+"Report-Msgid-Bugs-To: <vdr-bugs@tvdr.de>\n"
"POT-Creation-Date: 2007-10-13 11:52+0200\n"
"PO-Revision-Date: 2008-03-17 19:52+0100\n"
"Last-Translator: Adrian Caval <anrxc@sysphere.org>\n"
diff --git a/PLUGINS/src/hello/po/hu_HU.po b/PLUGINS/src/hello/po/hu_HU.po
index c349a761..30791323 100644
--- a/PLUGINS/src/hello/po/hu_HU.po
+++ b/PLUGINS/src/hello/po/hu_HU.po
@@ -1,5 +1,5 @@
# VDR plugin language source file.
-# Copyright (C) 2008 Klaus Schmidinger <kls@cadsoft.de>
+# Copyright (C) 2008 Klaus Schmidinger <kls@tvdr.de>
# This file is distributed under the same license as the VDR package.
# Istvan Koenigsberger <istvnko@hotmail.com>, 2002
# Guido Josten <guido.josten@t-online.de>, 2002
@@ -7,7 +7,7 @@
msgid ""
msgstr ""
"Project-Id-Version: VDR 1.6.0\n"
-"Report-Msgid-Bugs-To: <vdr-bugs@cadsoft.de>\n"
+"Report-Msgid-Bugs-To: <vdr-bugs@tvdr.de>\n"
"POT-Creation-Date: 2007-10-13 11:52+0200\n"
"PO-Revision-Date: 2007-08-11 12:34+0200\n"
"Last-Translator: Istvan Koenigsberger <istvnko@hotmail.com>, Guido Josten <guido.josten@t-online.de>\n"
diff --git a/PLUGINS/src/hello/po/it_IT.po b/PLUGINS/src/hello/po/it_IT.po
index e4295c6e..0f221608 100644
--- a/PLUGINS/src/hello/po/it_IT.po
+++ b/PLUGINS/src/hello/po/it_IT.po
@@ -1,12 +1,12 @@
# VDR plugin language source file.
-# Copyright (C) 2008 Klaus Schmidinger <kls@cadsoft.de>
+# Copyright (C) 2008 Klaus Schmidinger <kls@tvdr.de>
# This file is distributed under the same license as the VDR package.
# Diego Pierotto <vdr-italian@tiscali.it>, 2008
#
msgid ""
msgstr ""
"Project-Id-Version: VDR 1.6.0\n"
-"Report-Msgid-Bugs-To: <vdr-bugs@cadsoft.de>\n"
+"Report-Msgid-Bugs-To: <vdr-bugs@tvdr.de>\n"
"POT-Creation-Date: 2007-10-13 11:52+0200\n"
"PO-Revision-Date: 2008-01-27 20:11+0100\n"
"Last-Translator: Diego Pierotto <vdr-italian@tiscali.it>\n"
diff --git a/PLUGINS/src/hello/po/nl_NL.po b/PLUGINS/src/hello/po/nl_NL.po
index 0eb798ff..5ea7b6a7 100644
--- a/PLUGINS/src/hello/po/nl_NL.po
+++ b/PLUGINS/src/hello/po/nl_NL.po
@@ -1,5 +1,5 @@
# VDR plugin language source file.
-# Copyright (C) 2008 Klaus Schmidinger <kls@cadsoft.de>
+# Copyright (C) 2008 Klaus Schmidinger <kls@tvdr.de>
# This file is distributed under the same license as the VDR package.
# Arnold Niessen <niessen@iae.nl> <arnold.niessen@philips.com>, 2001
# Hans Dingemans <hans.dingemans@tacticalops.nl>, 2003
@@ -8,7 +8,7 @@
msgid ""
msgstr ""
"Project-Id-Version: VDR 1.6.0\n"
-"Report-Msgid-Bugs-To: <vdr-bugs@cadsoft.de>\n"
+"Report-Msgid-Bugs-To: <vdr-bugs@tvdr.de>\n"
"POT-Creation-Date: 2007-10-13 11:52+0200\n"
"PO-Revision-Date: 2007-08-11 12:34+0200\n"
"Last-Translator: Maarten Wisse <Maarten.Wisse@urz.uni-hd.de>\n"
diff --git a/PLUGINS/src/hello/po/nn_NO.po b/PLUGINS/src/hello/po/nn_NO.po
index 9b3682da..400c864f 100644
--- a/PLUGINS/src/hello/po/nn_NO.po
+++ b/PLUGINS/src/hello/po/nn_NO.po
@@ -1,5 +1,5 @@
# VDR plugin language source file.
-# Copyright (C) 2008 Klaus Schmidinger <kls@cadsoft.de>
+# Copyright (C) 2008 Klaus Schmidinger <kls@tvdr.de>
# This file is distributed under the same license as the VDR package.
# Jřrgen Tvedt <pjtvedt@online.no>, 2001
# Truls Slevigen <truls@slevigen.no>, 2002
@@ -7,7 +7,7 @@
msgid ""
msgstr ""
"Project-Id-Version: VDR 1.6.0\n"
-"Report-Msgid-Bugs-To: <vdr-bugs@cadsoft.de>\n"
+"Report-Msgid-Bugs-To: <vdr-bugs@tvdr.de>\n"
"POT-Creation-Date: 2007-10-13 11:52+0200\n"
"PO-Revision-Date: 2007-08-11 12:34+0200\n"
"Last-Translator: Truls Slevigen <truls@slevigen.no>\n"
diff --git a/PLUGINS/src/hello/po/pl_PL.po b/PLUGINS/src/hello/po/pl_PL.po
index 0d6c6960..07bff4d3 100644
--- a/PLUGINS/src/hello/po/pl_PL.po
+++ b/PLUGINS/src/hello/po/pl_PL.po
@@ -1,12 +1,12 @@
# VDR plugin language source file.
-# Copyright (C) 2008 Klaus Schmidinger <kls@cadsoft.de>
+# Copyright (C) 2008 Klaus Schmidinger <kls@tvdr.de>
# This file is distributed under the same license as the VDR package.
# Michael Rakowski <mrak@gmx.de>, 2002
#
msgid ""
msgstr ""
"Project-Id-Version: VDR 1.6.0\n"
-"Report-Msgid-Bugs-To: <vdr-bugs@cadsoft.de>\n"
+"Report-Msgid-Bugs-To: <vdr-bugs@tvdr.de>\n"
"POT-Creation-Date: 2007-10-13 11:52+0200\n"
"PO-Revision-Date: 2007-08-11 12:34+0200\n"
"Last-Translator: Michael Rakowski <mrak@gmx.de>\n"
diff --git a/PLUGINS/src/hello/po/pt_PT.po b/PLUGINS/src/hello/po/pt_PT.po
index 7cca3704..3d7a09fd 100644
--- a/PLUGINS/src/hello/po/pt_PT.po
+++ b/PLUGINS/src/hello/po/pt_PT.po
@@ -1,12 +1,12 @@
# VDR plugin language source file.
-# Copyright (C) 2008 Klaus Schmidinger <kls@cadsoft.de>
+# Copyright (C) 2008 Klaus Schmidinger <kls@tvdr.de>
# This file is distributed under the same license as the VDR package.
# Paulo Lopes <pmml@netvita.pt>, 2001
#
msgid ""
msgstr ""
"Project-Id-Version: VDR 1.6.0\n"
-"Report-Msgid-Bugs-To: <vdr-bugs@cadsoft.de>\n"
+"Report-Msgid-Bugs-To: <vdr-bugs@tvdr.de>\n"
"POT-Creation-Date: 2007-10-13 11:52+0200\n"
"PO-Revision-Date: 2007-08-11 12:34+0200\n"
"Last-Translator: Paulo Lopes <pmml@netvita.pt>\n"
diff --git a/PLUGINS/src/hello/po/ro_RO.po b/PLUGINS/src/hello/po/ro_RO.po
index 87df8e42..7562690d 100644
--- a/PLUGINS/src/hello/po/ro_RO.po
+++ b/PLUGINS/src/hello/po/ro_RO.po
@@ -1,5 +1,5 @@
# VDR plugin language source file.
-# Copyright (C) 2008 Klaus Schmidinger <kls@cadsoft.de>
+# Copyright (C) 2008 Klaus Schmidinger <kls@tvdr.de>
# This file is distributed under the same license as the VDR package.
# Paul Lacatus <paul@campina.iiruc.ro>, 2002
# Lucian Muresan <lucianm@users.sourceforge.net>, 2004
@@ -7,7 +7,7 @@
msgid ""
msgstr ""
"Project-Id-Version: VDR 1.6.0\n"
-"Report-Msgid-Bugs-To: <vdr-bugs@cadsoft.de>\n"
+"Report-Msgid-Bugs-To: <vdr-bugs@tvdr.de>\n"
"POT-Creation-Date: 2007-10-13 11:52+0200\n"
"PO-Revision-Date: 2007-08-11 12:34+0200\n"
"Last-Translator: Lucian Muresan <lucianm@users.sourceforge.net>\n"
diff --git a/PLUGINS/src/hello/po/ru_RU.po b/PLUGINS/src/hello/po/ru_RU.po
index c7d1ea9b..5544ff82 100644
--- a/PLUGINS/src/hello/po/ru_RU.po
+++ b/PLUGINS/src/hello/po/ru_RU.po
@@ -1,12 +1,12 @@
# VDR plugin language source file.
-# Copyright (C) 2008 Klaus Schmidinger <kls@cadsoft.de>
+# Copyright (C) 2008 Klaus Schmidinger <kls@tvdr.de>
# This file is distributed under the same license as the VDR package.
# Vyacheslav Dikonov <sdiconov@mail.ru>, 2004
#
msgid ""
msgstr ""
"Project-Id-Version: VDR 1.6.0\n"
-"Report-Msgid-Bugs-To: <vdr-bugs@cadsoft.de>\n"
+"Report-Msgid-Bugs-To: <vdr-bugs@tvdr.de>\n"
"POT-Creation-Date: 2007-10-13 11:52+0200\n"
"PO-Revision-Date: 2007-08-11 12:34+0200\n"
"Last-Translator: Vyacheslav Dikonov <sdiconov@mail.ru>\n"
diff --git a/PLUGINS/src/hello/po/sl_SI.po b/PLUGINS/src/hello/po/sl_SI.po
index cf27896a..cc489a49 100644
--- a/PLUGINS/src/hello/po/sl_SI.po
+++ b/PLUGINS/src/hello/po/sl_SI.po
@@ -1,5 +1,5 @@
# VDR plugin language source file.
-# Copyright (C) 2008 Klaus Schmidinger <kls@cadsoft.de>
+# Copyright (C) 2008 Klaus Schmidinger <kls@tvdr.de>
# This file is distributed under the same license as the VDR package.
# Miha Setina <mihasetina@softhome.net>, 2000
# Matjaz Thaler <matjaz.thaler@guest.arnes.si>, 2003
@@ -7,7 +7,7 @@
msgid ""
msgstr ""
"Project-Id-Version: VDR 1.6.0\n"
-"Report-Msgid-Bugs-To: <vdr-bugs@cadsoft.de>\n"
+"Report-Msgid-Bugs-To: <vdr-bugs@tvdr.de>\n"
"POT-Creation-Date: 2007-10-13 11:52+0200\n"
"PO-Revision-Date: 2007-08-11 12:34+0200\n"
"Last-Translator: Matjaz Thaler <matjaz.thaler@guest.arnes.si>\n"
diff --git a/PLUGINS/src/hello/po/sv_SE.po b/PLUGINS/src/hello/po/sv_SE.po
index b3c0cc20..a390fcfb 100644
--- a/PLUGINS/src/hello/po/sv_SE.po
+++ b/PLUGINS/src/hello/po/sv_SE.po
@@ -1,5 +1,5 @@
# VDR plugin language source file.
-# Copyright (C) 2008 Klaus Schmidinger <kls@cadsoft.de>
+# Copyright (C) 2008 Klaus Schmidinger <kls@tvdr.de>
# This file is distributed under the same license as the VDR package.
# Tomas Prybil <tomas@prybil.se>, 2002
# Jan Ekholm <chakie@infa.abo.fi>, 2003
@@ -7,7 +7,7 @@
msgid ""
msgstr ""
"Project-Id-Version: VDR 1.6.0\n"
-"Report-Msgid-Bugs-To: <vdr-bugs@cadsoft.de>\n"
+"Report-Msgid-Bugs-To: <vdr-bugs@tvdr.de>\n"
"POT-Creation-Date: 2007-10-13 11:52+0200\n"
"PO-Revision-Date: 2007-08-11 12:34+0200\n"
"Last-Translator: Tomas Prybil <tomas@prybil.se>\n"
diff --git a/PLUGINS/src/hello/po/tr_TR.po b/PLUGINS/src/hello/po/tr_TR.po
index 4202881d..34f627fa 100644
--- a/PLUGINS/src/hello/po/tr_TR.po
+++ b/PLUGINS/src/hello/po/tr_TR.po
@@ -1,12 +1,12 @@
# VDR plugin language source file.
-# Copyright (C) 2008 Klaus Schmidinger <kls@cadsoft.de>
+# Copyright (C) 2008 Klaus Schmidinger <kls@tvdr.de>
# This file is distributed under the same license as the VDR package.
# Oktay Yolgeçen <oktay_73@yahoo.de>, 2007
#
msgid ""
msgstr ""
"Project-Id-Version: VDR 1.6.0\n"
-"Report-Msgid-Bugs-To: <vdr-bugs@cadsoft.de>\n"
+"Report-Msgid-Bugs-To: <vdr-bugs@tvdr.de>\n"
"POT-Creation-Date: 2007-10-13 11:52+0200\n"
"PO-Revision-Date: 2008-05-12 22:34:4800\n"
"Last-Translator: Oktay Yolgeçen <oktay_73@yahoo.de>\n"
diff --git a/PLUGINS/src/osddemo/README b/PLUGINS/src/osddemo/README
index 96f8912b..50d36d8c 100644
--- a/PLUGINS/src/osddemo/README
+++ b/PLUGINS/src/osddemo/README
@@ -1,10 +1,10 @@
This is a "plugin" for the Video Disk Recorder (VDR).
-Written by: Klaus Schmidinger <kls@cadsoft.de>
+Written by: Klaus Schmidinger <kls@tvdr.de>
-Project's homepage: http://www.cadsoft.de/vdr
+Project's homepage: http://www.tvdr.de
-Latest version available at: http://www.cadsoft.de/vdr
+Latest version available at: http://www.tvdr.de
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
diff --git a/PLUGINS/src/pictures/Makefile b/PLUGINS/src/pictures/Makefile
index d9499443..46a262f2 100644
--- a/PLUGINS/src/pictures/Makefile
+++ b/PLUGINS/src/pictures/Makefile
@@ -1,7 +1,7 @@
#
# Makefile for a Video Disk Recorder plugin
#
-# $Id: Makefile 1.2 2008/01/13 13:00:04 kls Exp $
+# $Id: Makefile 2.1 2009/10/18 14:02:41 kls Exp $
# The official name of this plugin.
# This name will be used in the '-P...' option of VDR to load the plugin.
@@ -79,7 +79,7 @@ I18Npot = $(PODIR)/$(PLUGIN).pot
msgfmt -c -o $@ $<
$(I18Npot): $(wildcard *.c)
- xgettext -C -cTRANSLATORS --no-wrap --no-location -k -ktr -ktrNOOP --msgid-bugs-address='<vdr-bugs@cadsoft.de>' -o $@ $^
+ xgettext -C -cTRANSLATORS --no-wrap --no-location -k -ktr -ktrNOOP --msgid-bugs-address='<vdr-bugs@tvdr.de>' -o $@ $^
%.po: $(I18Npot)
msgmerge -U --no-wrap --no-location --backup=none -q $@ $<
diff --git a/PLUGINS/src/pictures/README b/PLUGINS/src/pictures/README
index bd6bb7d2..bc21526b 100644
--- a/PLUGINS/src/pictures/README
+++ b/PLUGINS/src/pictures/README
@@ -1,10 +1,10 @@
This is a "plugin" for the Video Disk Recorder (VDR).
-Written by: Klaus Schmidinger <kls@cadsoft.de>
+Written by: Klaus Schmidinger <kls@tvdr.de>
-Project's homepage: www.cadsoft.de/vdr
+Project's homepage: http://www.tvdr.de
-Latest version available at: www.cadsoft.de/vdr
+Latest version available at: http://www.tvdr.de
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
diff --git a/PLUGINS/src/pictures/po/de_DE.po b/PLUGINS/src/pictures/po/de_DE.po
index 62811aec..abeaa6e1 100644
--- a/PLUGINS/src/pictures/po/de_DE.po
+++ b/PLUGINS/src/pictures/po/de_DE.po
@@ -1,15 +1,15 @@
# VDR plugin language source file.
-# Copyright (C) 2008 Klaus Schmidinger <kls@cadsoft.de>
+# Copyright (C) 2008 Klaus Schmidinger <kls@tvdr.de>
# This file is distributed under the same license as the VDR package.
-# Klaus Schmidinger <kls@cadsoft.de>, 2008
+# Klaus Schmidinger <kls@tvdr.de>, 2008
#
msgid ""
msgstr ""
"Project-Id-Version: VDR 1.6.0\n"
-"Report-Msgid-Bugs-To: <vdr-bugs@cadsoft.de>\n"
+"Report-Msgid-Bugs-To: <vdr-bugs@tvdr.de>\n"
"POT-Creation-Date: 2008-01-12 17:38+0100\n"
"PO-Revision-Date: 2008-01-12 17:41+0100\n"
-"Last-Translator: Klaus Schmidinger <kls@cadsoft.de>\n"
+"Last-Translator: Klaus Schmidinger <kls@tvdr.de>\n"
"Language-Team: German\n"
"MIME-Version: 1.0\n"
"Content-Type: text/plain; charset=ISO-8859-15\n"
diff --git a/PLUGINS/src/pictures/po/fi_FI.po b/PLUGINS/src/pictures/po/fi_FI.po
index 932807fa..bbcb6972 100644
--- a/PLUGINS/src/pictures/po/fi_FI.po
+++ b/PLUGINS/src/pictures/po/fi_FI.po
@@ -1,12 +1,12 @@
# VDR plugin language source file.
-# Copyright (C) 2008 Klaus Schmidinger <kls@cadsoft.de>
+# Copyright (C) 2008 Klaus Schmidinger <kls@tvdr.de>
# This file is distributed under the same license as the VDR package.
# Rolf Ahrenberg <rahrenbe@cc.hut.fi>, 2008
#
msgid ""
msgstr ""
"Project-Id-Version: VDR 1.6.0\n"
-"Report-Msgid-Bugs-To: <vdr-bugs@cadsoft.de>\n"
+"Report-Msgid-Bugs-To: <vdr-bugs@tvdr.de>\n"
"POT-Creation-Date: 2008-01-12 17:38+0100\n"
"PO-Revision-Date: 2008-01-12 17:41+0100\n"
"Last-Translator: Rolf Ahrenberg <rahrenbe@cc.hut.fi>\n"
diff --git a/PLUGINS/src/pictures/po/fr_FR.po b/PLUGINS/src/pictures/po/fr_FR.po
index 2d71adb4..c42d9ba1 100644
--- a/PLUGINS/src/pictures/po/fr_FR.po
+++ b/PLUGINS/src/pictures/po/fr_FR.po
@@ -1,12 +1,12 @@
# VDR plugin language source file.
-# Copyright (C) 2008 Klaus Schmidinger <kls@cadsoft.de>
+# Copyright (C) 2008 Klaus Schmidinger <kls@tvdr.de>
# This file is distributed under the same license as the VDR package.
# Patrice Staudt <patrice.staudt@laposte.net>, 2008
#
msgid ""
msgstr ""
"Project-Id-Version: VDR 1.6.0\n"
-"Report-Msgid-Bugs-To: <vdr-bugs@cadsoft.de>\n"
+"Report-Msgid-Bugs-To: <vdr-bugs@tvdr.de>\n"
"POT-Creation-Date: 2008-01-12 17:38+0100\n"
"PO-Revision-Date: 2008-01-12 17:41+0100\n"
"Last-Translator: Patrice Staudt <patrice.staudt@laposte.net>\n"
diff --git a/PLUGINS/src/pictures/po/it_IT.po b/PLUGINS/src/pictures/po/it_IT.po
index 62d0bdff..d30f040b 100644
--- a/PLUGINS/src/pictures/po/it_IT.po
+++ b/PLUGINS/src/pictures/po/it_IT.po
@@ -1,12 +1,12 @@
# VDR plugin language source file.
-# Copyright (C) 2008 Klaus Schmidinger <kls@cadsoft.de>
+# Copyright (C) 2008 Klaus Schmidinger <kls@tvdr.de>
# This file is distributed under the same license as the VDR package.
# Diego Pierotto <vdr-italian@tiscali.it>, 2008
#
msgid ""
msgstr ""
"Project-Id-Version: VDR 1.6.0\n"
-"Report-Msgid-Bugs-To: <vdr-bugs@cadsoft.de>\n"
+"Report-Msgid-Bugs-To: <vdr-bugs@tvdr.de>\n"
"POT-Creation-Date: 2008-01-12 17:38+0100\n"
"PO-Revision-Date: 2008-01-27 20:22+0100\n"
"Last-Translator: Diego Pierotto <vdr-italian@tiscali.it>\n"
diff --git a/PLUGINS/src/pictures/po/ru_RU.po b/PLUGINS/src/pictures/po/ru_RU.po
index d88f3ef6..46ed5c52 100644
--- a/PLUGINS/src/pictures/po/ru_RU.po
+++ b/PLUGINS/src/pictures/po/ru_RU.po
@@ -1,12 +1,12 @@
# VDR plugin language source file.
-# Copyright (C) 2008 Klaus Schmidinger <kls@cadsoft.de>
+# Copyright (C) 2008 Klaus Schmidinger <kls@tvdr.de>
# This file is distributed under the same license as the VDR package.
# Alexander Gross <Bikalexander@gmail.com>, 2008
#
msgid ""
msgstr ""
"Project-Id-Version: VDR 1.6.0\n"
-"Report-Msgid-Bugs-To: <vdr-bugs@cadsoft.de>\n"
+"Report-Msgid-Bugs-To: <vdr-bugs@tvdr.de>\n"
"POT-Creation-Date: 2008-01-12 17:38+0100\n"
"PO-Revision-Date: 2008-03-14 00:45+0100\n"
"Last-Translator: Alexander Gross <Bikalexander@gmail.com>\n"
diff --git a/PLUGINS/src/servicedemo/README b/PLUGINS/src/servicedemo/README
index db7ad5b9..95bbc01b 100644
--- a/PLUGINS/src/servicedemo/README
+++ b/PLUGINS/src/servicedemo/README
@@ -2,9 +2,9 @@ This is a "plugin" for the Video Disk Recorder (VDR).
Written by: Udo Richter <udo_richter@gmx.de>
-Project's homepage: www.cadsoft.de/vdr
+Project's homepage: http://www.tvdr.de
-Latest version available at: www.cadsoft.de/vdr
+Latest version available at: http://www.tvdr.de
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
diff --git a/PLUGINS/src/skincurses/Makefile b/PLUGINS/src/skincurses/Makefile
index 4dc4e28a..cade7957 100644
--- a/PLUGINS/src/skincurses/Makefile
+++ b/PLUGINS/src/skincurses/Makefile
@@ -1,7 +1,7 @@
#
# Makefile for a Video Disk Recorder plugin
#
-# $Id: Makefile 1.15 2008/01/19 11:40:33 kls Exp $
+# $Id: Makefile 2.1 2009/10/18 14:03:30 kls Exp $
# The official name of this plugin.
# This name will be used in the '-P...' option of VDR to load the plugin.
@@ -79,7 +79,7 @@ I18Npot = $(PODIR)/$(PLUGIN).pot
msgfmt -c -o $@ $<
$(I18Npot): $(wildcard *.c)
- xgettext -C -cTRANSLATORS --no-wrap --no-location -k -ktr -ktrNOOP --msgid-bugs-address='<vdr-bugs@cadsoft.de>' -o $@ $^
+ xgettext -C -cTRANSLATORS --no-wrap --no-location -k -ktr -ktrNOOP --msgid-bugs-address='<vdr-bugs@tvdr.de>' -o $@ $^
%.po: $(I18Npot)
msgmerge -U --no-wrap --no-location --backup=none -q $@ $<
diff --git a/PLUGINS/src/skincurses/README b/PLUGINS/src/skincurses/README
index b6ad9ec3..20b56541 100644
--- a/PLUGINS/src/skincurses/README
+++ b/PLUGINS/src/skincurses/README
@@ -1,10 +1,10 @@
This is a "plugin" for the Video Disk Recorder (VDR).
-Written by: Klaus Schmidinger <kls@cadsoft.de>
+Written by: Klaus Schmidinger <kls@tvdr.de>
-Project's homepage: www.cadsoft.de/vdr
+Project's homepage: http://www.tvdr.de
-Latest version available at: www.cadsoft.de/vdr
+Latest version available at: http://www.tvdr.de
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
diff --git a/PLUGINS/src/skincurses/po/de_DE.po b/PLUGINS/src/skincurses/po/de_DE.po
index 5e3ce2ca..ccf2de6a 100644
--- a/PLUGINS/src/skincurses/po/de_DE.po
+++ b/PLUGINS/src/skincurses/po/de_DE.po
@@ -1,15 +1,15 @@
# VDR plugin language source file.
-# Copyright (C) 2008 Klaus Schmidinger <kls@cadsoft.de>
+# Copyright (C) 2008 Klaus Schmidinger <kls@tvdr.de>
# This file is distributed under the same license as the VDR package.
-# Klaus Schmidinger <kls@cadsoft.de>, 2007
+# Klaus Schmidinger <kls@tvdr.de>, 2007
#
msgid ""
msgstr ""
"Project-Id-Version: VDR 1.6.0\n"
-"Report-Msgid-Bugs-To: <vdr-bugs@cadsoft.de>\n"
+"Report-Msgid-Bugs-To: <vdr-bugs@tvdr.de>\n"
"POT-Creation-Date: 2007-08-15 16:04+0200\n"
"PO-Revision-Date: 2007-08-15 16:07+0200\n"
-"Last-Translator: Klaus Schmidinger <kls@cadsoft.de>\n"
+"Last-Translator: Klaus Schmidinger <kls@tvdr.de>\n"
"Language-Team: German\n"
"MIME-Version: 1.0\n"
"Content-Type: text/plain; charset=ISO-8859-15\n"
diff --git a/PLUGINS/src/skincurses/po/fi_FI.po b/PLUGINS/src/skincurses/po/fi_FI.po
index 89779cca..71f7297e 100644
--- a/PLUGINS/src/skincurses/po/fi_FI.po
+++ b/PLUGINS/src/skincurses/po/fi_FI.po
@@ -1,12 +1,12 @@
# VDR plugin language source file.
-# Copyright (C) 2008 Klaus Schmidinger <kls@cadsoft.de>
+# Copyright (C) 2008 Klaus Schmidinger <kls@tvdr.de>
# This file is distributed under the same license as the VDR package.
# Rolf Ahrenberg <rahrenbe@cc.hut.fi>, 2007
#
msgid ""
msgstr ""
"Project-Id-Version: VDR 1.6.0\n"
-"Report-Msgid-Bugs-To: <vdr-bugs@cadsoft.de>\n"
+"Report-Msgid-Bugs-To: <vdr-bugs@tvdr.de>\n"
"POT-Creation-Date: 2007-08-14 20:54+0300\n"
"PO-Revision-Date: 2007-08-14 20:48+0300\n"
"Last-Translator: Rolf Ahrenberg <rahrenbe@cc.hut.fi>\n"
diff --git a/PLUGINS/src/skincurses/po/it_IT.po b/PLUGINS/src/skincurses/po/it_IT.po
index 038b6e52..3355fe89 100644
--- a/PLUGINS/src/skincurses/po/it_IT.po
+++ b/PLUGINS/src/skincurses/po/it_IT.po
@@ -1,12 +1,12 @@
# VDR plugin language source file.
-# Copyright (C) 2008 Klaus Schmidinger <kls@cadsoft.de>
+# Copyright (C) 2008 Klaus Schmidinger <kls@tvdr.de>
# This file is distributed under the same license as the VDR package.
# Diego Pierotto <vdr-italian@tiscali.it>, 2008
#
msgid ""
msgstr ""
"Project-Id-Version: VDR 1.6.0\n"
-"Report-Msgid-Bugs-To: <vdr-bugs@cadsoft.de>\n"
+"Report-Msgid-Bugs-To: <vdr-bugs@tvdr.de>\n"
"POT-Creation-Date: 2007-08-15 16:04+0200\n"
"PO-Revision-Date: 2008-01-27 20:35+0100\n"
"Last-Translator: Diego Pierotto <vdr-italian@tiscali.it>\n"
diff --git a/PLUGINS/src/skincurses/po/ru_RU.po b/PLUGINS/src/skincurses/po/ru_RU.po
index 609071ed..afb2530b 100644
--- a/PLUGINS/src/skincurses/po/ru_RU.po
+++ b/PLUGINS/src/skincurses/po/ru_RU.po
@@ -1,12 +1,12 @@
# VDR plugin language source file.
-# Copyright (C) 2008 Klaus Schmidinger <kls@cadsoft.de>
+# Copyright (C) 2008 Klaus Schmidinger <kls@tvdr.de>
# This file is distributed under the same license as the VDR package.
# Alexander Gross <Bikalexander@gmail.com>, 2008
#
msgid ""
msgstr ""
"Project-Id-Version: VDR 1.6.0\n"
-"Report-Msgid-Bugs-To: <vdr-bugs@cadsoft.de>\n"
+"Report-Msgid-Bugs-To: <vdr-bugs@tvdr.de>\n"
"POT-Creation-Date: 2007-08-15 16:04+0200\n"
"PO-Revision-Date: 2008-03-14 00:21+0100\n"
"Last-Translator: Alexander Gross <Bikalexander@gmail.com>\n"
diff --git a/PLUGINS/src/sky/README b/PLUGINS/src/sky/README
index 51b2d51d..19d5d988 100644
--- a/PLUGINS/src/sky/README
+++ b/PLUGINS/src/sky/README
@@ -1,10 +1,10 @@
This is a "plugin" for the Video Disk Recorder (VDR).
-Written by: Klaus Schmidinger <kls@cadsoft.de>
+Written by: Klaus Schmidinger <kls@tvdr.de>
-Project's homepage: www.cadsoft.de/vdr
+Project's homepage: http://www.tvdr.de
-Latest version available at: www.cadsoft.de/vdr
+Latest version available at: http://www.tvdr.de
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
diff --git a/PLUGINS/src/status/README b/PLUGINS/src/status/README
index f7bcd2f4..b73e6be2 100644
--- a/PLUGINS/src/status/README
+++ b/PLUGINS/src/status/README
@@ -1,10 +1,10 @@
This is a "plugin" for the Video Disk Recorder (VDR).
-Written by: Klaus Schmidinger <kls@cadsoft.de>
+Written by: Klaus Schmidinger <kls@tvdr.de>
-Project's homepage: www.cadsoft.de/people/kls/vdr
+Project's homepage: http://www.tvdr.de
-Latest version available at: www.cadsoft.de/people/kls/vdr/software.htm
+Latest version available at: http://www.tvdr.de
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
diff --git a/PLUGINS/src/svdrpdemo/README b/PLUGINS/src/svdrpdemo/README
index 4ca6821d..8ae9e8ad 100644
--- a/PLUGINS/src/svdrpdemo/README
+++ b/PLUGINS/src/svdrpdemo/README
@@ -1,10 +1,10 @@
This is a "plugin" for the Video Disk Recorder (VDR).
-Written by: Klaus Schmidinger <Klaus.Schmidinger@cadsoft.de>
+Written by: Klaus Schmidinger <Klaus.Schmidinger@tvdr.de>
-Project's homepage: http://www.cadsoft.de/vdr
+Project's homepage: http://www.tvdr.de
-Latest version available at: http://www.cadsoft.de/vdr
+Latest version available at: http://www.tvdr.de
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
diff --git a/PLUGINS/src/sky/getskyepg.pl b/PLUGINS/src/sky/getskyepg.pl
index d42744dd..dfca96a5 100755
--- a/PLUGINS/src/sky/getskyepg.pl
+++ b/PLUGINS/src/sky/getskyepg.pl
@@ -8,7 +8,7 @@
#
# See the README file for copyright information and how to reach the author.
#
-# $Id: getskyepg.pl 1.7 2008/03/22 10:17:42 kls Exp $
+# $Id: getskyepg.pl 2.1 2009/10/18 14:05:47 kls Exp $
use Getopt::Std;
use Time::Local;
@@ -35,10 +35,10 @@ $User = $opt_U;
# See "Rules for using this data" on http://bleb.org/tv/data/listings.
# In case you modify this script in a way that changes its behavior
# towards the www.bleb.org website, please replace 'vdrbugs@cadsoft.de'
# with your own email address! That way Andrew Flegg <andrew@bleb.org>,
# who runs that web site, can contact you in case of problems.
-$IDENT = "VDR::getskyepg.pl, http://www.cadsoft.de/vdr - vdrbugs\@cadsoft.de";
+$IDENT = "VDR::getskyepg.pl, http://www.tvdr.de - vdr-bugs\@tvdr.de";
$GAP = 2;
$SkyWebPage = "www.bleb.org/tv/data/listings";
@@ -35,10 +35,10 @@ $User = $opt_U;
# See "Rules for using this data" on http://bleb.org/tv/data/listings.
# In case you modify this script in a way that changes its behavior
-# towards the www.bleb.org website, please replace 'vdrbugs@cadsoft.de'
+# towards the www.bleb.org website, please replace 'vdr-bugs@tvdr.de'
# with your own email address! That way Andrew Flegg <andrew@bleb.org>,
# who runs that web site, can contact you in case of problems.